"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const defaultExperimentOptions = {
    isEligible: true,
};
function createExPlatClientReactHelpers(exPlatClient) {
    const useExperiment = (experimentName, providedOptions = {}) => {
        console.log('useExperiment start');
        const options = {
            ...defaultExperimentOptions,
            ...providedOptions,
        };
        // Manual updates to ensure rerendering when we want it:
        // https://legacy.reactjs.org/docs/hooks-faq.html#is-there-something-like-forceupdate
        const [, forceUpdate] = (0, react_1.useReducer)((x) => x + 1, 0);
        const previousExperimentNameRef = (0, react_1.useRef)(experimentName);
        (0, react_1.useEffect)(() => {
            console.log('useExperiment useEffect');
            let isSubscribed = true;
            if (options.isEligible) {
                console.log('useExperiment useEffect loadExperimentAssignment', experimentName);
                exPlatClient.loadExperimentAssignment(experimentName).then((v) => {
                    console.log('useExperiment loadExperimentAssignment promise resolution', v);
                    if (isSubscribed) {
                        console.log('useExperiment loadExperimentAssignment promise resolution forceUpdate()');
                        forceUpdate();
                    }
                });
            }
            return () => {
                isSubscribed = false;
            };
        }, [experimentName, options.isEligible]);
        if (experimentName !== previousExperimentNameRef.current &&
            !previousExperimentNameRef.current.startsWith('explat_test')) {
            exPlatClient.config.logError({
                message: '[ExPlat] useExperiment: experimentName should never change between renders!',
            });
        }
        console.log('useExperiment end', options.isEligible);
        if (!options.isEligible) {
            return [false, null];
        }
        const maybeExperimentAssignment = exPlatClient.dangerouslyGetMaybeLoadedExperimentAssignment(experimentName);
        console.log('useExperiment end', [!maybeExperimentAssignment, maybeExperimentAssignment]);
        return [!maybeExperimentAssignment, maybeExperimentAssignment];
    };
    const Experiment = ({ defaultExperience, treatmentExperience, loadingExperience, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        if (isLoading) {
            return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: loadingExperience });
        }
        else if (!experimentAssignment?.variationName) {
            return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: defaultExperience });
        }
        return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: treatmentExperience });
    };
    const ProvideExperimentData = ({ children, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        return children(isLoading, experimentAssignment);
    };
    return {
        useExperiment,
        Experiment,
        ProvideExperimentData,
    };
}
exports.default = createExPlatClientReactHelpers;
//# sourceMappingURL=index.js.map