import { Fragment as _Fragment, jsx as _jsx } from "react/jsx-runtime";
import { useRef, useEffect, useReducer } from 'react';
const defaultExperimentOptions = {
    isEligible: true,
};
export default function createExPlatClientReactHelpers(exPlatClient) {
    const useExperiment = (experimentName, providedOptions = {}) => {
        console.log('useExperiment start');
        const options = {
            ...defaultExperimentOptions,
            ...providedOptions,
        };
        // Manual updates to ensure rerendering when we want it:
        // https://legacy.reactjs.org/docs/hooks-faq.html#is-there-something-like-forceupdate
        const [, forceUpdate] = useReducer((x) => x + 1, 0);
        const previousExperimentNameRef = useRef(experimentName);
        useEffect(() => {
            console.log('useExperiment useEffect');
            let isSubscribed = true;
            if (options.isEligible) {
                console.log('useExperiment useEffect loadExperimentAssignment', experimentName);
                exPlatClient.loadExperimentAssignment(experimentName).then((v) => {
                    console.log('useExperiment loadExperimentAssignment promise resolution', v);
                    if (isSubscribed) {
                        console.log('useExperiment loadExperimentAssignment promise resolution forceUpdate()');
                        forceUpdate();
                    }
                });
            }
            return () => {
                isSubscribed = false;
            };
        }, [experimentName, options.isEligible]);
        if (experimentName !== previousExperimentNameRef.current &&
            !previousExperimentNameRef.current.startsWith('explat_test')) {
            exPlatClient.config.logError({
                message: '[ExPlat] useExperiment: experimentName should never change between renders!',
            });
        }
        console.log('useExperiment end', options.isEligible);
        if (!options.isEligible) {
            return [false, null];
        }
        const maybeExperimentAssignment = exPlatClient.dangerouslyGetMaybeLoadedExperimentAssignment(experimentName);
        console.log('useExperiment end', [!maybeExperimentAssignment, maybeExperimentAssignment]);
        return [!maybeExperimentAssignment, maybeExperimentAssignment];
    };
    const Experiment = ({ defaultExperience, treatmentExperience, loadingExperience, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        if (isLoading) {
            return _jsx(_Fragment, { children: loadingExperience });
        }
        else if (!experimentAssignment?.variationName) {
            return _jsx(_Fragment, { children: defaultExperience });
        }
        return _jsx(_Fragment, { children: treatmentExperience });
    };
    const ProvideExperimentData = ({ children, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        return children(isLoading, experimentAssignment);
    };
    return {
        useExperiment,
        Experiment,
        ProvideExperimentData,
    };
}
//# sourceMappingURL=index.js.map